# Jarvis: A simple CLI tool for interacting with ChatGPT

Say hello to `jarvis`, an awesome tool that conveniently allows you to converse with ChatGPT right from your terminal!

## Usage

To manually set your OpenAI API key, use the `-k` (or `--key`) argument:
```
jarvis -k <YOUR_API_KEY_HERE>
```

To start talking to jarvis, simply type:
```
jarvis
```

## Future Work

- Option to save conversations so they can be continued in a later session
- Option to enter multi-line prompts
- Option to stop or regenerate response